==> qt-creator-opensource-src-4.12.0.zip: qt-creator-opensource-src-4.12.0/src/plugins/webassembly/webassemblyqtversion.h <==
/****************************************************************************
**
** Copyright (C) 2019 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <qtsupport/qtversionfactory.h>
#include <qtsupport/baseqtversion.h>

namespace WebAssembly {
namespace Internal {

class WebAssemblyQtVersion : public QtSupport::BaseQtVersion
{
public:
    WebAssemblyQtVersion();

    QString description() const override;

    QSet<Core::Id> targetDeviceTypes() const override;
};

class WebAssemblyQtVersionFactory : public QtSupport::QtVersionFactory
{
public:
    WebAssemblyQtVersionFactory();
};

} // namespace Internal
} // namespace WebAssembly

==> qt-creator-opensource-src-4.15.0.zip: qt-creator-opensource-src-4.15.0/src/plugins/webassembly/webassemblyqtversion.h <==
/****************************************************************************
**
** Copyright (C) 2020 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <qtsupport/qtversionfactory.h>
#include <qtsupport/baseqtversion.h>

namespace WebAssembly {
namespace Internal {

class WebAssemblyQtVersion : public QtSupport::BaseQtVersion
{
    Q_DECLARE_TR_FUNCTIONS(WebAssembly::Internal::WebAssemblyQtVersion)

public:
    WebAssemblyQtVersion();

    QString description() const override;

    QSet<Utils::Id> targetDeviceTypes() const override;

    bool isValid() const override;
    QString invalidReason() const override;

    static const QtSupport::QtVersionNumber &minimumSupportedQtVersion();
    static bool isQtVersionInstalled();
    static bool isUnsupportedQtVersionInstalled();
};

class WebAssemblyQtVersionFactory : public QtSupport::QtVersionFactory
{
public:
    WebAssemblyQtVersionFactory();
};

} // namespace Internal
} // namespace WebAssembly
